@@ -118,7 +118,7 @@ def evaluate(adata: ad.AnnData,
     # plot UMAP embeddings
     if draw:
         if color_by is None:
-            color_by = [cell_type_col] if need_batch is None else [batch_col, cell_type_col]
+            color_by = [batch_col, cell_type_col] if need_batch else [cell_type_col]
         if cluster_key is not None:
             color_by = [cluster_key] + color_by
         fig = draw_embeddings(adata=adata, color_by=color_by, min_dist=min_dist, spread=spread,
